uaudp: removed old/unused code (#if 0...#endif)
[metze/wireshark/wip.git] / file.h
diff --git a/file.h b/file.h
index 198e20a23011578452077df81349bb9943a1ba97..3088435a609606f3ac4c19fdd3f1f4a0b6d19c7b 100644 (file)
--- a/file.h
+++ b/file.h
@@ -5,7 +5,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef __FILE_H__
@@ -63,18 +63,11 @@ typedef enum {
     cf_cb_file_retap_finished,
     cf_cb_file_merge_started, /* Qt only */
     cf_cb_file_merge_finished, /* Qt only */
-    cf_cb_file_fast_save_finished, /* GTK+ only? */
-    cf_cb_packet_selected, /* GTK+ only. */
-    cf_cb_packet_unselected, /* GTK+ only. */
-    cf_cb_field_unselected, /* GTK+ only. */
+    cf_cb_file_fast_save_finished,
     cf_cb_file_save_started,
     cf_cb_file_save_finished,
     cf_cb_file_save_failed,
-    cf_cb_file_save_stopped,
-    cf_cb_file_export_specified_packets_started, /* GTK+ only. */
-    cf_cb_file_export_specified_packets_finished, /* GTK+ only. */
-    cf_cb_file_export_specified_packets_failed, /* GTK+ only. */
-    cf_cb_file_export_specified_packets_stopped /* GTK+ only. */
+    cf_cb_file_save_stopped
 } cf_cbs;
 
 typedef void (*cf_callback_t) (gint event, gpointer data, gpointer user_data);
@@ -152,13 +145,13 @@ cf_read_status_t cf_read(capture_file *cf, gboolean from_save);
  *
  * @param cf the capture file from which to read the record
  * @param fdata the frame_data structure for the record in question
* @param phdr pointer to a wtap_pkthdr structure to contain the
  * record's metadata
  * @param buf a Buffer into which to read the record's raw data
  * @return TRUE if the read succeeded, FALSE if there was an error
  */
 gboolean cf_read_record_r(capture_file *cf, const frame_data *fdata,
-                          struct wtap_pkthdr *phdr, Buffer *buf);
+                          wtap_rec *rec, Buffer *buf);
 
 /**
  * Read the metadata and raw data for a record into a
@@ -606,13 +599,6 @@ void cf_select_packet(capture_file *cf, int row);
  */
 void cf_unselect_packet(capture_file *cf);
 
-/**
- * Unselect all protocol tree fields, if any.
- *
- * @param cf the capture file
- */
-void cf_unselect_field(capture_file *cf);
-
 /**
  * Mark a particular frame in a particular capture.
  *
@@ -152,13 +145,13 @@ cf_read_status_t cf_read(capture_file *cf, gboolean from_save);
  * @param cf the capture file from which to read the record
  * @param fdata the frame_data structure for the record in question
- * @param phdr pointer to a wtap_pkthdr structure to contain the
+ * @param rec pointer to a wtap_rec structure to contain the
  * record's metadata
  * @param buf a Buffer into which to read the record's raw data